	subroutine mc_calo (p_spec, th_spec, dpp, x, y, z, dxdz, dydz,
     >		x_fp, dx_fp, y_fp, dy_fp, m2,
     >		ms_flag, wcs_flag, decay_flag, resmult, frx,fry, ok_spec, 
     >          pathlen,using_tgt_field,zi,ztemp,drift_to_cal)

C+______________________________________________________________________________
!
! Monte-Carlo of Ge/Gm calorimeter.
!	Note that we only pass on real*8 variables to the subroutine.
!	This will make life easier for portability.
!
! Author: David Gaskell
!
! Modification History:
!
!  30-Sep-2002  Just smear the input variables.	
C-______________________________________________________________________________

	implicit 	none

	include '../constants.inc'
        include '../spectrometers.inc'

! Spectrometer definitions

	integer*4 spectr
	parameter (spectr = 5)		!calo is spec #5.

! Collimator (octagon) dimensions.

	real*8 h_entr,v_entr,h_exit,v_exit



! No collimator - wide open
!	parameter (h_entr = 99.)
!	parameter (v_entr = 99.)
!	parameter (h_exit = 99.)
!	parameter (v_exit = 99.)

! 'large' collimator.
c	parameter (h_entr = 7.201)
c	parameter (v_entr = 4.696)
c	parameter (h_exit = 7.567)
c	parameter (v_exit = 4.935)

! No collimator, but use collimatro dimnsions to define calo
	parameter (h_entr = 64.0)
	parameter (v_entr = 109.0)
	parameter (h_exit = 64.0)
	parameter (v_exit = 109.0)

! z-position of important apertures.            
        real*8 z_entr,z_exit
        parameter (z_entr = 365.0d0)		!nominally 1.263 m
        parameter (z_exit = z_entr + 6.3d0)	!6.3 cm thick

! Math constants

	real*8 d_r,r_d
	parameter (d_r = pi/180.)
	parameter (r_d = 180./pi)

! The arguments

	real*8 x,y,z				!(cm)
	real*8 dpp				!delta p/p (%)
	real*8 dxdz,dydz			!X,Y slope in spectrometer
	real*8 x_fp,y_fp,dx_fp,dy_fp		!Focal plane values to return
	real*8 p_spec,th_spec			!spectrometer setting
	real*8 fry,frx				!vertical position@tgt (+y=down)
	real*8 pathlen
	logical ms_flag				!mult. scattering flag
	logical wcs_flag			!wire chamber smearing flag
	logical decay_flag			!check for particle decay
	logical ok_spec				!true if particle makes it
	logical using_tgt_field

! Local declarations.

	integer*4	chan	/1/,n_classes

	logical	first_time_here/.true./

	real*8 dpp_recon,dth_recon,dph_recon	!reconstructed quantities
	real*8 y_recon
	real*8 ps,p,m2				!More kinematic variables.
	real*8 xt,yt,rt,tht			!temporaries
	real*8 resmult				!DC resolution factor
	real*8 dummy
	real*8 zdrift

	logical dflag			!has particle decayed?
	logical ok

	real*8 ctheta,stheta                      !cos and sin of tgt angle

	real*8 grnd

	real*8 tmpwidth				!used for aperture cut.
	real*8 gauss1
	real*8 ztemp,zi
	real*8 delta_z,delta_y

	real*8 drift_to_cal

	save		!Remember it all!

! ================================ Executable Code =============================
	ctheta = cos(th_spec)	! GAW
	stheta = sin(th_spec)	! GAW


! Initialize ok_spec to .false., reset decay flag

	ok_spec = .false.
	dflag = .false.			!particle has not decayed yet

! Save spectrometer coordinates.

	xs = x
	ys = y
	zs = z
	dxdzs = dxdz
	dydzs = dydz

! particle momentum

	dpps = dpp
	p = p_spec*(1.+dpps/100.)

! Begin transporting particle.

! Do transformations, checking against apertures.
! Check front of fixed slit.  (here slit = calo)

	  zdrift = drift_to_cal
	  call project(xs,ys,zdrift,decay_flag,dflag,m2,p,pathlen)
	  if (abs(ys).gt.h_entr) then
	    goto 500
	  endif
	  if (abs(xs).gt.v_entr) then
	    goto 500
	  endif

! replace xs,ys,... with 'tracked' quantities.
	  x_fp = xs + 0.4 * gauss1(99.0)
	  y_fp = ys + 0.4 * gauss1(99.0)

	  dx_fp = (x_fp-fry)/(drift_to_cal-zi*ctheta)
	  dy_fp = (y_fp-zi*stheta)/(drift_to_cal-zi*ctheta)

	  xs=x_fp
	  ys=y_fp
	  dxdzs=dx_fp
	  dydzs=dy_fp

	  ps = p*(1.0 + 0.05/sqrt(p/1000.0)*gauss1(99.0))
	  dpps = (ps/p_spec-1.0)*100.0
! Fill output to return to main code
	  delta_y = -frx*ctheta - ztemp*stheta
	  delta_z = frx*stheta + ztemp*ctheta
	  call mc_calo_recon(dpp_recon,dth_recon,dph_recon,y_recon,fry,delta_y,delta_z,drift_to_cal)

	  dpp = dpp_recon
	  dxdz = dph_recon
	  dydz = dth_recon
	  y = y_recon

          if (using_tgt_field) then
	     ok = .TRUE.
c	     write(6,*) 'calling track to target from mc_calo'
	     call track_to_tgt(dpp,y,dxdz,dydz,frx,-fry,
	1	  -p,sqrt(m2),ctheta,stheta,ztemp,-1,ok)
         endif
	  
	  ok_spec = .true.

500	continue

	return
	end
